@@ -35,7 +35,9 @@ Options:
   -s, --silent-progress    Suppress `tqdm` [default: False].
   --warn-binary  Don't silently skip files which appear to be binary data
                  [default: False].
-  -e, --show-email  Show author email instead of name [default: False].
+  --show=<info>  Author information to show [default: name]|email.
+                 Use 'name,email' to show both.
+  -e, --show-email  Shortcut for `--show=email`.
   --enum         Show row numbers [default: False].
   -t, --bytype             Show stats per file extension [default: False].
   -w, --ignore-whitespace  Ignore whitespace when comparing the parent's
@@ -85,14 +87,15 @@ __license__ = __licence__ # weird foreign language
 log = logging.getLogger(__name__)
 
 # processing `blame --line-porcelain`
-RE_AUTHS_BLAME = re.compile(r'^\w+ \d+ \d+ (\d+)\nauthor (.+?)$.*?\ncommitter-time (\d+)',
-                            flags=re.M | re.DOTALL)
+RE_AUTHS_BLAME = re.compile(
+    r'^\w+ \d+ \d+ (\d+)\nauthor (.+?)\nauthor-mail <(.+?)>$.*?\ncommitter-time (\d+)',
+    flags=re.M | re.DOTALL)
 RE_NCOM_AUTH_EM = re.compile(r'^\s*(\d+)\s+(.*?)\s+<(.*)>\s*$', flags=re.M)
 RE_BLAME_BOUNDS = re.compile(
     r'^\w+\s+\d+\s+\d+(\s+\d+)?\s*$[^\t]*?^boundary\s*$[^\t]*?^\t.*?$\r?\n',
     flags=re.M | re.DOTALL)
-# processing `log --format="aN%aN ct%ct" --numstat`
-RE_AUTHS_LOG = re.compile(r"^aN(.+?) ct(\d+)\n\n", flags=re.M)
+# processing `log --format="aN%aN aE%aE ct%ct" --numstat`
+RE_AUTHS_LOG = re.compile(r"^aN(.+?) aE(.+?) ct(\d+)\n\n", flags=re.M)
 RE_STAT_BINARY = re.compile(r"^\s*?-\s*-.*?\n", flags=re.M)
 RE_RENAME = re.compile(r"\{.+? => (.+?)\}")
 # finds all non-escaped commas
@@ -104,6 +107,8 @@ COST_HOURS = {'commit', 'commits', 'hour', 'hours'}
 CHURN_SLOC = {'surv', 'survive', 'surviving'}
 CHURN_INS = {'ins', 'insert', 'insertion', 'insertions', 'add', 'addition', 'additions', '+'}
 CHURN_DEL = {'del', 'deletion', 'deletions', 'delete', '-'}
+SHOW_NAME = {'name', 'n'}
+SHOW_EMAIL = {'email', 'e'}
 
 
 def hours(dates, maxCommitDiffInSec=120 * 60, firstCommitAdditionInMinutes=120):
@@ -207,11 +212,12 @@ def tabulate(auth_stats, stats_tot, sort='loc', bytype=False, backend='md', cost
 
 def _get_auth_stats(gitdir, branch="HEAD", since=None, include_files=None, exclude_files=None,
                     silent_progress=False, ignore_whitespace=False, M=False, C=False,
-                    warn_binary=False, bytype=False, show_email=False, prefix_gitdir=False,
-                    churn=None, ignore_rev="", ignore_revs_file=None, until=None):
+                    warn_binary=False, bytype=False, show=None, prefix_gitdir=False, churn=None,
+                    ignore_rev="", ignore_revs_file=None, until=None):
     """Returns dict: {"<author>": {"loc": int, "files": {}, "commits": int, "ctimes": [int]}}"""
     until = ["--until", until] if until else []
     since = ["--since", since] if since else []
+    show = show or SHOW_NAME
     git_cmd = ["git", "-C", gitdir]
     log.debug("base command:%s", git_cmd)
     file_list = check_output(git_cmd + ["ls-files", "--with-tree", branch]).strip().split('\n')
@@ -239,7 +245,7 @@ def _get_auth_stats(gitdir, branch="HEAD", since=None, include_files=None, exclu
         if ignore_revs_file:
             base_cmd.extend(["--ignore-revs-file", ignore_revs_file])
     else:
-        base_cmd = git_cmd + ["log", "--format=aN%aN ct%ct", "--numstat"] + since + until
+        base_cmd = git_cmd + ["log", "--format=aN%aN aE%aE ct%ct", "--numstat"] + since + until
 
     if ignore_whitespace:
         base_cmd.append("-w")
@@ -291,8 +297,9 @@ def _get_auth_stats(gitdir, branch="HEAD", since=None, include_files=None, exclu
                 # preventing user with nearest commit to boundary owning the LOC
                 blame_out = RE_BLAME_BOUNDS.sub('', blame_out)
 
-            for loc, auth, tstamp in RE_AUTHS_BLAME.findall(blame_out): # for each chunk
+            for loc, name, email, tstamp in RE_AUTHS_BLAME.findall(blame_out): # for each chunk
                 loc = int(loc)
+                auth = f'{name} <{email}>'
                 stats_append(fname, auth, loc, tstamp)
 
     else:
@@ -308,8 +315,9 @@ def _get_auth_stats(gitdir, branch="HEAD", since=None, include_files=None, exclu
         blame_out = RE_STAT_BINARY.sub('', blame_out)
 
         blame_out = RE_AUTHS_LOG.split(blame_out)
-        blame_out = zip(blame_out[1::3], blame_out[2::3], blame_out[3::3])
-        for auth, tstamp, fnames in blame_out:
+        blame_out = zip(blame_out[1::4], blame_out[2::4], blame_out[3::4], blame_out[4::4])
+        for name, email, tstamp, fnames in blame_out:
+            auth = f'{name} <{email}>'
             fnames = fnames.split('\naN', 1)[0]
             for i in fnames.strip().split('\n'):
                 try:
@@ -329,20 +337,23 @@ def _get_auth_stats(gitdir, branch="HEAD", since=None, include_files=None, exclu
         stats.setdefault("commits", 0)
     log.debug(RE_NCOM_AUTH_EM.findall(auth_commits.strip()))
     auth2em = {}
-    for (ncom, auth, em) in RE_NCOM_AUTH_EM.findall(auth_commits.strip()):
-        auth = str(auth)
-        auth2em[auth] = em # TODO: count most used email?
+    auth2name = {}
+    for (ncom, name, em) in RE_NCOM_AUTH_EM.findall(auth_commits.strip()):
+        auth = f'{name} <{em}>'
+        auth2em[auth] = em
+        auth2name[auth] = name
         try:
             auth_stats[auth]["commits"] += int(ncom)
         except KeyError:
             auth_stats[auth] = {"loc": 0, "files": set(), "commits": int(ncom), "ctimes": []}
-    if show_email:         # replace author name with email
-        log.debug(auth2em)
+    if not (show & SHOW_NAME and show & SHOW_EMAIL): # replace author with either email or name
+        auth2new = auth2em if (show & SHOW_EMAIL) else auth2name
+        log.debug(auth2new)
         old = auth_stats
         auth_stats = {}
 
         for auth, stats in getattr(old, 'iteritems', old.items)():
-            i = auth_stats.setdefault(auth2em[auth],
+            i = auth_stats.setdefault(auth2new[auth],
                                       {"loc": 0, "files": set(), "commits": 0, "ctimes": []})
             i["loc"] += stats["loc"]
             i["files"].update(stats["files"])
@@ -361,6 +372,10 @@ def run(args):
         log.warning("--sort argument (%s) unrecognised\n%s", args.sort, __doc__)
         raise KeyError(args.sort)
 
+    args.show = set(args.show.lower().split(','))
+    if args.show_email:
+        args.show = SHOW_EMAIL
+
     if not args.excl:
         args.excl = ""
 
@@ -429,7 +444,7 @@ def run(args):
                       include_files=include_files, exclude_files=exclude_files,
                       silent_progress=args.silent_progress,
                       ignore_whitespace=args.ignore_whitespace, M=args.M, C=args.C,
-                      warn_binary=args.warn_binary, bytype=args.bytype, show_email=args.show_email,
+                      warn_binary=args.warn_binary, bytype=args.bytype, show=args.show,
                       prefix_gitdir=len(gitdirs) > 1, churn=churn, ignore_rev=args.ignore_rev,
                       ignore_revs_file=args.ignore_revs_file)
 
